# Copyright 2023 Qilimanjaro Quantum Tech
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""This module contains the QProgram class and all the needed information to build a QProgram.

.. currentmodule:: qililab

QProgram Class
~~~~~~~~~~~~~~~~

.. autosummary::
    :toctree: api

    ~QProgram

Compilers
~~~~~~~~~

.. currentmodule:: qililab.qprogram

.. autosummary::
    :toctree: api

    ~QbloxCompiler
"""
from .qblox_compiler import QbloxCompiler
from .qprogram import QProgram
from .quantum_machines_compiler import QuantumMachinesCompiler
from .variable import Domain
